confint: Draw polygon confidence intervals

Description Usage Arguments

View source: R/model.object.helper.functions.r

Description

just a call to polygon but with more intuitive arguments in the context on making confidence intervals. You need to call this before you overlay your median with the line function.

Usage

1
confint(x, ylow, yhigh, ...)

Arguments

x

the independent variable vector

ylow

the lower confidence interval y series

yhigh

the higher confidence interval y series

...

other argument from par that can be used with the polygon function


duplisea/ddhelper documentation built on Nov. 4, 2019, 11:04 a.m.