Description Usage Arguments Author(s)
View source: R/data.helper.functions.r
a function to convert degrees, minutes, seconds coordinates into decimal degrees.
1 | decdeg.f(degminsec)
|
degminsec |
all in one number without commas or decimals, e.g. 44 38' 52", input as 443852 |
Daniel Duplisea
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.