map.inset.f: An inset map for the main map function

Description Usage Arguments Examples

View source: R/plotting.helper.functions.r

Description

A simple stripped down map without annotation that can be used as an inset to the larger scale map

Usage

1
2
map.inset.f(longs = c(-71, -50), lats = c(43, 52.25),
  land.colour = "sienna3", sea.colour = "lightblue")

Arguments

longs

longitude decimal degrees (- for western hemisphere)

lats

latitude decimal degrees (- for southern hemisphere)

land.col

colour of the land

sea.col

colour of the oceans and water bodies

Examples

1
2
3
4
5
6
7
   #old.par= par()
   map.f(longs=c(-74,-50),lats=c(43,52.25),isob=c(200,400))
 	par(fig = c(.1,0.4,.6,.9), new = T) #position of the inset box on the current map
 	map.inset.f(longs=c(-130,-40),lats=c(10,65)) #coordinates of land area covered by inset
 	rect(-70,43,-50,52.25,border="blue",lwd=1) #smaller area highlighted in the inset
 	box(lwd=2,col="black")
 	par(old.par)

duplisea/ddhelper documentation built on Nov. 4, 2019, 11:04 a.m.