push: Push a value onto the end of vector

Description Usage Arguments Value Author(s) References

View source: R/data.helper.functions.r

Description

pushes values onto the end of vector. Used by data science people when they do not know how big their final object size should be. You do not need to assign the vector to itself again, it is done internally so somewhat against the R way of doing things and it could get you into trouble

Usage

1
push(vec, item)

Arguments

vec

vector of data

item

the new values you want to append

Value

a vector with new values pushed onto the end of the old vector

Author(s)

Kevin Wright

References

Kevin Wright http://www.johnmyleswhite.com/notebook/2009/12/07/implementing-push-and-pop-in-r/#comment-17810


duplisea/ddhelper documentation built on Nov. 4, 2019, 11:04 a.m.