View source: R/model.object.helper.functions.r
just a call to polygon but with more intuitive arguments in the context on making confidence intervals. You need to call this before you overlay your median with the line function.
1 |
x |
the independent variable vector |
ylow |
the lower confidence interval y series |
yhigh |
the higher confidence interval y series |
... |
other argument from par that can be used with the polygon function |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.