Description Usage Arguments Value Author(s) Examples
View source: R/data.helper.functions.r
mimics count(distinct value) in mysql when using a group by statement. Used most in apply.
1 |
x |
The vector for which you want distinct values counted |
a scalar with the count of unique values in a vector
Daniel Duplisea
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.