Description Usage Arguments Value Author(s) References
View source: R/data.helper.functions.r
pushes values onto the end of vector. Used by data science people when they do not know how big their final object size should be. You do not need to assign the vector to itself again, it is done internally so somewhat against the R way of doing things and it could get you into trouble
1 | push(vec, item)
|
vec |
vector of data |
item |
the new values you want to append |
a vector with new values pushed onto the end of the old vector
Kevin Wright
Kevin Wright http://www.johnmyleswhite.com/notebook/2009/12/07/implementing-push-and-pop-in-r/#comment-17810
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.